==> haskell-wai-cors-0.2.7-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-cors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-cors
version: 0.2.7
id: wai-cors-0.2.7-FCkDCkhH2JsHpeXSRt02po
key: wai-cors-0.2.7-FCkDCkhH2JsHpeXSRt02po
license: MIT
copyright: (c) 2015-2019 Lars Kuhtz <lakuhtz@gmail.com>,
           (c) 2014 AlephCloud Systems, Inc.
maintainer: Lars Kuhtz <lakuhtz@gmail.com>
author: Lars Kuhtz <lakuhtz@gmail.com>
homepage: https://github.com/larskuhtz/wai-cors
synopsis: CORS for WAI
description:
    This package provides an implemenation of
    Cross-Origin resource sharing (CORS) for
    <http://hackage.haskell.org/package/wai Wai>
    that aims to be compliant with <http://www.w3.org/TR/cors>.
category: HTTP, Network, Web, Wai
abi: fd8e535ba3bddca2d6a57f1413d03079
exposed: True
exposed-modules:
    Network.Wai.Middleware.Cors
import-dirs: /usr/lib/ghc-8.6.5/site-local/wai-cors-0.2.7
library-dirs: /usr/lib/ghc-8.6.5/site-local/wai-cors-0.2.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wai-cors-0.2.7
hs-libraries: HSwai-cors-0.2.7-FCkDCkhH2JsHpeXSRt02po
depends:
    attoparsec-0.13.2.3-BbILE9CT2Wt3O8KWGStqZj base-4.12.0.0
    base-unicode-symbols-0.2.4.2-3LxD4JMUgh71uDhEzsDAiJ
    bytestring-0.10.8.2 case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    http-types-0.12.3-Coz39hkYXV9BhDskHfFaoY mtl-2.2.2
    transformers-0.5.6.2 wai-3.2.2.1-7G70zI5dy01FNHM6AAlnXL
haddock-interfaces: /usr/share/doc/haskell-wai-cors/html/wai-cors.haddock
haddock-html: /usr/share/doc/haskell-wai-cors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-cors-0.2.7-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-cors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-cors
version: 0.2.7
id: wai-cors-0.2.7-BnpOF6BrhKNKezWzw1g1VK
key: wai-cors-0.2.7-BnpOF6BrhKNKezWzw1g1VK
license: MIT
copyright: (c) 2015-2019 Lars Kuhtz <lakuhtz@gmail.com>,
           (c) 2014 AlephCloud Systems, Inc.
maintainer: Lars Kuhtz <lakuhtz@gmail.com>
author: Lars Kuhtz <lakuhtz@gmail.com>
homepage: https://github.com/larskuhtz/wai-cors
synopsis: CORS for WAI
description:
    This package provides an implemenation of
    Cross-Origin resource sharing (CORS) for
    <http://hackage.haskell.org/package/wai Wai>
    that aims to be compliant with <http://www.w3.org/TR/cors>.
category: HTTP, Network, Web, Wai
abi: 6b5f64ae7ba5dc4debb6cb355862206a
exposed: True
exposed-modules:
    Network.Wai.Middleware.Cors
import-dirs: /usr/lib/ghc-8.6.5/site-local/wai-cors-0.2.7
library-dirs: /usr/lib/ghc-8.6.5/site-local/wai-cors-0.2.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wai-cors-0.2.7
hs-libraries: HSwai-cors-0.2.7-BnpOF6BrhKNKezWzw1g1VK
depends:
    attoparsec-0.13.2.3-BbILE9CT2Wt3O8KWGStqZj base-4.12.0.0
    base-unicode-symbols-0.2.4.2-3LxD4JMUgh71uDhEzsDAiJ
    bytestring-0.10.8.2 case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    http-types-0.12.3-KiHBR3VW7LN81D4RBDuP1U mtl-2.2.2
    transformers-0.5.6.2 wai-3.2.2.1-LiO6tjlOPxLE7Ud9tulQOy
haddock-interfaces: /usr/share/doc/haskell-wai-cors/html/wai-cors.haddock
haddock-html: /usr/share/doc/haskell-wai-cors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
